@@ -86,10 +86,11 @@ class _GraceDbLogStream(object):
             self._queue.task_done()
 
     def write(self, text):
-        with self._lock:
-            if self._closed:
-                raise RuntimeError('Log handler is already closed')
-            self._queue.put(text)
+        if text.strip():
+            with self._lock:
+                if self._closed:
+                    raise RuntimeError('Log handler is already closed')
+                self._queue.put(text)
 
     def close(self):
         with self._lock:
