@@ -754,7 +754,7 @@ class GraceDb(GsiRest):
                 filecontents = sys.stdin.read()
             else:
                 filecontents = open(filename, "rb").read()
-        elif isinstance(filecontents, file):
+        elif hasattr(filecontents, 'read'):
             # XXX Does not scale well.
             filecontents = filecontents.read()
         files = [('upload', os.path.basename(filename), filecontents)]
@@ -817,7 +817,7 @@ class GraceDb(GsiRest):
                     filecontents = sys.stdin.read()
                 else:
                     filecontents = open(filename, "rb").read()
-            elif isinstance(filecontents, file):
+            elif hasattr(filecontents, 'read'):
                 # XXX Does not scale well.
                 filecontents = filecontents.read()
             files = [('upload', os.path.basename(filename), filecontents)]
@@ -1262,28 +1262,36 @@ def encode_multipart_formdata(fields, files):
     files is a sequence of (name, filename, value) elements for data to be uploaded as files
     Return (content_type, body) ready for httplib.HTTP instance
     """
-    BOUNDARY = '----------ThIs_Is_tHe_bouNdaRY_$'
-    CRLF = '\r\n'
+    BOUNDARY = b'----------ThIs_Is_tHe_bouNdaRY_$'
+    CRLF = b'\r\n'
     L = []
     for (key, value) in fields:
         if value is None: continue
-        L.append('--' + BOUNDARY)
-        L.append('Content-Disposition: form-data; name="%s"' % key)
-        L.append('')
-        # str(value) in case it is unicode
-        L.append(str(value))
+        L.append(b'--' + BOUNDARY)
+        L.append(b'Content-Disposition: form-data; name="%s"' % key.encode())
+        L.append(b'')
+        # encode in case it is unicode
+        if isinstance(value, six.binary_type):
+            L.append(value)
+        elif isinstance(value, six.text_type):
+            L.append(value.encode())
+        else:
+            L.append(str(value).encode())
     for (key, filename, value) in files:
         if value is None: continue
-        L.append('--' + BOUNDARY)
+        L.append(b'--' + BOUNDARY)
         # str(filename) in case it is unicode
-        L.append('Content-Disposition: form-data; name="%s"; filename="%s"' % (key, str(filename)))
-        L.append('Content-Type: %s' % get_content_type(filename))
-        L.append('')
-        L.append(value)
-    L.append('--' + BOUNDARY + '--')
-    L.append('')
+        L.append(b'Content-Disposition: form-data; name="%s"; filename="%s"' % (key.encode(), filename.encode()))
+        L.append(b'Content-Type: %s' % get_content_type(filename).encode())
+        L.append(b'')
+        if isinstance(value, six.text_type):
+            L.append(value.encode())
+        else:
+            L.append(value)
+    L.append(b'--' + BOUNDARY + b'--')
+    L.append(b'')
     body = CRLF.join(L)
-    content_type = 'multipart/form-data; boundary=%s' % BOUNDARY
+    content_type = b'multipart/form-data; boundary=%s' % BOUNDARY
     return content_type, body
 
 def get_content_type(filename):
