@@ -174,10 +174,10 @@ class TestMain(TestGraceDb):
         self.assertEqual(r.status, 201) # CREATED
         r_content = r.json()
         link = r_content['permalink']
-        self.assertEqual(open(uploadFile, 'r').read(),
+        self.assertEqual(open(uploadFile, 'rb').read(),
             self._gracedb.get(self._gracedb.files(self._eventId).json()
             ['big.data']).read())
-        self.assertEqual(open(uploadFile, 'r').read(),
+        self.assertEqual(open(uploadFile, 'rb').read(),
             self._gracedb.get(link).read())
 
     def test_upload_file(self):
@@ -189,11 +189,11 @@ class TestMain(TestGraceDb):
         r_content = r.json()
         link = r_content['permalink']
 
-        self.assertEqual(open(uploadFile, 'r').read(),
+        self.assertEqual(open(uploadFile, 'rb').read(),
             self._gracedb.get(self._gracedb.files(self._eventId).json()
             ['upload.data']).read())
 
-        self.assertEqual(open(uploadFile, 'r').read(),
+        self.assertEqual(open(uploadFile, 'rb').read(),
             self._gracedb.get(link).read())
 
         # Re-upload slightly different file.
@@ -204,11 +204,11 @@ class TestMain(TestGraceDb):
         r_content = r.json()
         link2 = r_content['permalink']
 
-        self.assertEqual(open(uploadFile2, 'r').read(),
+        self.assertEqual(open(uploadFile2, 'rb').read(),
             self._gracedb.get(self._gracedb.files(self._eventId).json()
             ['upload.data']).read())
 
-        self.assertEqual(open(uploadFile2, 'r').read(),
+        self.assertEqual(open(uploadFile2, 'rb').read(),
             self._gracedb.get(link2).read())
 
         self.assertNotEqual(link, link2)
@@ -356,7 +356,7 @@ class TestMain(TestGraceDb):
             handler.close()
 
         event_logs = self._gracedb.logs(graceid).read()
-        self.assertTrue(message in event_logs)
+        self.assertTrue(message.encode() in event_logs)
 
     def test_issue717(self):
         # non-backwards-compatibility of cli.Client import.
@@ -370,7 +370,7 @@ class TestMain(TestGraceDb):
     def test_gittag(self):
         # try to make sure GIT_TAG is set properly.
         import errno
-        version = "1.27"
+        version = "1.28"
         try:
             # If we are in the source dir (setup.py is available)
             # make sure the version above agrees.
